@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@
 SelectionTypeDialog::SelectionTypeDialog(bool backupData, QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Select Type"));
+    setWindowTitle(i18nc("@title:window", "Select Type"));
     setModal(true);
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
